import { useCallback, useEffect, useRef } from 'react';
import { MOUSE_MOVE_CLICK_THRESHOLD } from '../constants/render.constants';
const UserInput = ({ onClick, onRightClick, onPan, onScroll, onScale }) => {
    const mouseLastSeen = useRef();
    const mouseFirstSeen = useRef();
    const controlPressed = useRef(false);
    const mouseDown = useRef();
    const handleMouseUp = useCallback((e) => {
        if (!mouseFirstSeen.current || !onClick) {
            return;
        }
        // Check the delta in coors between the down and up to see if we've moved or should handle it as a click
        const deltaX = Math.abs(e.x - mouseFirstSeen.current.x);
        const deltaY = Math.abs(e.y - mouseFirstSeen.current.y);
        if (deltaX > MOUSE_MOVE_CLICK_THRESHOLD || deltaY > MOUSE_MOVE_CLICK_THRESHOLD) {
            return;
        }
        onClick(e.x, e.y, { altKey: e.altKey, ctrlKey: e.ctrlKey, metaKey: e.metaKey });
    }, [onClick]);
    const handleScale = useCallback((e) => {
        if (!onScale) {
            return;
        }
        e.preventDefault();
        onScale(e.deltaY);
    }, [onScale]);
    const handleScroll = useCallback((e) => {
        if (!onScroll) {
            return;
        }
        onScroll(e.deltaX, e.deltaY);
    }, [onScroll]);
    const handleWheel = useCallback((e) => {
        controlPressed.current ? handleScale(e) : handleScroll(e);
    }, [handleScale, handleScroll]);
    const handleMouseMove = useCallback((e) => {
        if (!mouseDown.current || !onPan) {
            return;
        }
        const lastSeen = mouseLastSeen.current || { x: 0, y: 0 };
        const xDiff = e.x - lastSeen.x;
        const yDiff = e.y - lastSeen.y;
        mouseLastSeen.current = {
            x: e.x,
            y: e.y,
        };
        onPan(xDiff, yDiff);
    }, [onPan]);
    useEffect(() => {
        window.addEventListener('mouseup', handleMouseUp);
        return () => {
            window.removeEventListener('mouseup', handleMouseUp);
        };
    }, [handleMouseUp]);
    useEffect(() => {
        window.addEventListener('wheel', handleWheel);
        return () => {
            window.removeEventListener('wheel', handleWheel);
        };
    }, [handleWheel]);
    useEffect(() => {
        window.addEventListener('mousemove', handleMouseMove);
        return () => {
            window.removeEventListener('mousemove', handleMouseMove);
        };
    }, [handleMouseMove]);
    /**
     * Track which keys are pressed
     */
    useEffect(() => {
        window.addEventListener('keydown', (e) => {
            if (e.key === 'Meta' || e.key === 'Control') {
                controlPressed.current = true;
            }
        });
        window.addEventListener('keyup', (e) => {
            if (e.key === 'Meta' || e.key === 'Control') {
                controlPressed.current = false;
            }
        });
    }, []);
    /**
     * Track mouse coordinate and mouse down state
     */
    useEffect(() => {
        window.addEventListener('mousedown', (e) => {
            mouseFirstSeen.current = {
                x: e.x,
                y: e.y,
            };
            mouseLastSeen.current = {
                x: e.x,
                y: e.y,
            };
            mouseDown.current = true;
        });
        window.addEventListener('mouseout', () => {
            mouseDown.current = false;
        });
        window.addEventListener('mouseup', () => {
            mouseDown.current = false;
        });
    }, []);
    return null;
};
export default UserInput;
