export declare type BlockNodeStyle = 'default' | 'info' | 'success' | 'warn' | 'danger';
export interface TreeNodeDisplay {
    collapsed?: boolean;
    faded?: boolean;
    block?: boolean;
    blockStyle?: BlockNodeStyle;
}
/**
 * Internal interfaces that don't have child nodes
 * This allows for extending without conflicting child node types
 */
interface __TreeNode {
    id: string;
    text: string;
    display?: TreeNodeDisplay;
}
interface __TreeNodeWithNodeSize extends __TreeNode {
    lines: string[];
    width: number;
    height: number;
    leafCount: number;
}
interface __TreeNodeWithTreeSize extends __TreeNodeWithNodeSize {
    treeHeight: number;
    treeWidth: number;
}
interface __TreeNodeWithLayout extends __TreeNodeWithTreeSize {
    x: number;
    y: number;
}
/**
 * Interfaces with child nodes for usage
 */
export interface TreeNode extends __TreeNode {
    nodes: TreeNode[];
}
export interface TreeNodeWithLayout extends __TreeNodeWithLayout {
    nodes: TreeNodeWithLayout[];
}
export interface TreeNodeWithTreeSize extends __TreeNodeWithTreeSize {
    nodes: TreeNodeWithTreeSize[];
}
/**
  @description
  Take a basic text/node tree, perform word wrapping
  Calculate the layout of the tree with the x/y of each child node being relative to it's parents node x/y
**/
export declare const getTreeLayout: (canvas2D: CanvasRenderingContext2D, node: TreeNode, maxWidth: number, fontSize: number) => TreeNodeWithLayout;
export {};
